@@ -1,3 +1,6 @@
+from builtins import str
+from builtins import map
+from builtins import object
 import re
 import textwrap
 from xml.sax.saxutils import quoteattr
@@ -28,8 +31,8 @@ def encode_attributes(iterable):
 
     Example:
 
-        >>> encode_attributes([('class', 'btn')])
-        u'class="btn"'
+        >>> encode_attributes([('class', 'btn')]) == 'class="btn"'
+        True
     """
     return ' '.join([
         u'{}={}'.format(attribute, quoteattr(value))
@@ -42,10 +45,10 @@ def prettify_text(text, indent=''):
 
     Example:
 
-        >>> prettify_text('   Test')
-        u'Test'
-        >>> prettify_text('       Test', indent='  ')
-        u'  Test'
+        >>> prettify_text('   Test') == 'Test'
+        True
+        >>> prettify_text('       Test', indent='  ') == '  Test'
+        True
     """
     text = textwrap.dedent(text).strip()
     out = []
@@ -65,7 +68,7 @@ class PrettifyElement(object):
         if element.tag:
             attributes = u''
             if element.attrib:
-                attributes = u' {}'.format(encode_attributes(element.items()))
+                attributes = u' {}'.format(encode_attributes(list(element.items())))
             self.out.append(u'{indent}<{tag}{attributes}>'.format(
                 indent=indent, tag=element.tag, attributes=attributes))
         if element.text and element.text.strip():
@@ -87,11 +90,8 @@ class PrettifyElement(object):
             text = prettify_text(element.tail, indent)
             self.out.append(text)
 
-    def __unicode__(self):
-        return u'\n'.join(self.out)
-
     def __str__(self):
-        return unicode(self).encode('utf-8')
+        return u'\n'.join(self.out)
 
 
 def _get_all_text_in_element(rootelement):
@@ -113,17 +113,14 @@ class Element(object):
     def __init__(self, element):
         self.element = element
 
-    def __unicode__(self):
+    def __str__(self):
         return tostring(self.element)
 
-    def __str__(self):
-        return unicode(self).encode('utf-8')
-
     def prettify(self, **kwargs):
-        return unicode(PrettifyElement(self.element, **kwargs))
+        return str(PrettifyElement(self.element, **kwargs))
 
     def prettyprint(self):
-        print self.prettify()
+        print(self.prettify())
 
     @property
     def tag(self):
@@ -181,14 +178,14 @@ class Element(object):
         """
         Get the CSS classes as a list.
         """
-        return re.split('\s+', self['class'])
+        return re.split('\s+', self['class'].strip())
 
     @property
     def cssclasses_set(self):
         """
         Get the CSS classes as a set.
         """
-        return set(re.split('\s+', self['class']))
+        return set(re.split('\s+', self['class'].strip()))
 
     def hasclass(self, cssclass):
         """
@@ -236,17 +233,14 @@ class S(object):
         """
         return html5lib.parse(self.html, treebuilder='lxml', namespaceHTMLElements=False)
 
-    def __unicode__(self):
+    def __str__(self):
         return tostring(self.parsed)
 
-    def __str__(self):
-        return unicode(self).encode('utf-8')
-
     def prettify(self, **kwargs):
-        return unicode(PrettifyElement(self.parsed.getroot(), **kwargs))
+        return str(PrettifyElement(self.parsed.getroot(), **kwargs))
 
     def prettyprint(self):
-        print self.prettify()
+        print(self.prettify())
 
     def list(self, cssselector):
         """
@@ -256,7 +250,7 @@ class S(object):
             List of :class:`.Element` objects.
         """
         selector = CSSSelector(cssselector)
-        return map(Element, selector(self.parsed))
+        return list(map(Element, selector(self.parsed)))
 
     def count(self, cssselector):
         """
@@ -270,7 +264,7 @@ class S(object):
         one element.
         """
         return bool(self.list(cssselector))
-        
+
     def one(self, cssselector):
         """
         Get exactly one match for the given CSS selector.
